
import React from 'react';
import { motion } from 'framer-motion';
import { Button } from '@/components/ui/button';
import { ChevronDown, PlayCircle } from 'lucide-react';

const HeroSection = () => {
  return (
    <section id="home" className="relative min-h-screen flex items-center justify-center overflow-hidden p-4 pt-20 bg-gradient-to-br from-purple-600 via-indigo-600 to-pink-500">
      <div className="absolute inset-0 opacity-20">
        <img  class="w-full h-full object-cover" alt="Cyclists riding in a vibrant city scene" src="https://images.unsplash.com/photo-1693138693965-f2ada0209162" />
      </div>
      
      <motion.div
        initial={{ opacity: 0, y: 50 }}
        animate={{ opacity: 1, y: 0 }}
        transition={{ duration: 0.8, ease: "easeOut" }}
        className="relative z-10 text-center bg-black/30 backdrop-blur-lg p-8 md:p-16 rounded-2xl shadow-2xl max-w-4xl mx-auto border border-white/20"
      >
        <motion.h1
          className="text-4xl sm:text-5xl md:text-6xl lg:text-7xl font-extrabold text-white mb-6 leading-tight"
          initial={{ opacity: 0, y: -30 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.7, delay: 0.2 }}
        >
          Markanızı <span className="text-yellow-400">Hareketlendirin</span>:
          <br />
          Sizin İçin <span className="bg-clip-text text-transparent bg-gradient-to-r from-pink-400 to-yellow-400">Pedallayalım!</span>
        </motion.h1>
        <motion.p
          className="text-lg md:text-xl text-white/90 mb-10 max-w-2xl mx-auto"
          initial={{ opacity: 0, y: -30 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.7, delay: 0.4 }}
        >
          Yenilikçi bisikletli reklam çözümlerimizle mesajınızı doğrudan hedef kitlenize ulaştırın. Çevre dostu, etkili ve unutulmaz.
        </motion.p>
        <motion.div
          className="flex flex-col sm:flex-row justify-center items-center space-y-4 sm:space-y-0 sm:space-x-6"
          initial={{ opacity: 0, y: -30 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.7, delay: 0.6 }}
        >
          <Button
            size="lg"
            className="bg-gradient-to-r from-yellow-400 to-orange-500 text-purple-900 font-bold hover:from-yellow-500 hover:to-orange-600 transition-all duration-300 transform hover:scale-105 shadow-xl px-10 py-3 text-lg rounded-full"
            onClick={() => document.getElementById('services')?.scrollIntoView({ behavior: 'smooth' })}
          >
            Daha Fazla Bilgi
          </Button>
          <Button
            variant="outline"
            size="lg"
            className="border-2 border-yellow-400 text-yellow-400 hover:bg-yellow-400 hover:text-purple-900 font-bold transition-all duration-300 transform hover:scale-105 shadow-xl px-10 py-3 text-lg rounded-full group"
          >
            <PlayCircle size={24} className="mr-2 transition-transform duration-300 group-hover:scale-110" />
            Tanıtım Videosu
          </Button>
        </motion.div>
      </motion.div>
      
      <motion.div
        className="absolute bottom-10 left-1/2 transform -translate-x-1/2"
        animate={{ y: [0, -12, 0] }}
        transition={{ duration: 1.8, repeat: Infinity, ease: "easeInOut" }}
      >
        <ChevronDown size={36} className="text-white/80" />
      </motion.div>
    </section>
  );
};

export default HeroSection;
